==> nextcloud-12.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/activity/l10n/lt_LT.js <==
OC.L10N.register(
    "activity",
    {
    "Activities" : "Veiklos",
    "An error occurred while loading activities" : "Įkeliant veiklas, įvyko klaida",
    "No activity yet" : "Kol kas nėra veiklos",
    "Load more activities" : "Įkelti daugiau veiklų",
    "Copied!" : "Nukopijuota!",
    "Not supported!" : "Nepalaikoma!",
    "Press ⌘-C to copy." : "Norėdami nukopijuoti, paspauskite ⌘-C.",
    "Press Ctrl-C to copy." : "Paspauskite Ctrl-C, kad nukopijuotumėte.",
    "{name} (invisible)" : "{name} (nematomas)",
    "{name} (restricted)" : "{name} (apribotas)",
    "in {path}" : "{path}",
    "This stream will show events like additions, changes & shares" : "Srautas rodo papildymus, pakeitimus ir bendrinimus",
    "There are no events for this filter" : "Nėra įvykių pasirinktam filtrui",
    "Today" : "Šiandien",
    "Yesterday" : "Vakar",
    "Personal activity feed for %s" : "%s asmeninis veiklos kanalas",
    "Your feed URL is invalid" : "Jūsų kanalo nuoroda yra neteisinga",
    "Your settings have been updated." : "Jūsų nustatymai atnaujinti.",
    "Settings have been updated." : "Nustatymai atnaujinti.",
    "Mail" : "Paštas",
    "Stream" : "Srautas",
    "All activities" : "Visos veiklos",
    "By others" : "Kitų",
    "By you" : "Jūsų",
    "\"remote user\"" : "\"naudotojas kitame serveryje\"",
    "Hello %s" : "Sveiki, %s",
    "Hello %s," : "Sveiki, %s,",
    "There was some activity at %s" : "%s buvo veiklos",
    "_and %n more _::_and %n more _" : ["ir %n kitas","ir %n kiti","ir %n kitų"],
    "Activity notification" : "Veiklos pranešimai",
    ", " : ",",
    "%s and %s" : "%s ir %s",
    "Activity" : "Veikla",
    "Activity feed" : "Veiklos kanalas",
    "Configure the default activity settings for new users." : "Nustatyti numatytas veiklas naujiems naudotojams",
    "List your own actions in the stream" : "Rodyti jūsų veiklą sraute",
    "Notify about your own actions via email" : "Informuoti apie mano veiksmus per el. paštą",
    "You need to set up your email address before you can receive notification emails." : "Jums turite nurodyti elektroninio pašto adresą norėdami gauti pranešimus.",
    "Send emails:" : "Siųsti el. laiškus:",
    "As soon as possible" : "Kuo greičiau",
    "Hourly" : "Kas valandą",
    "Daily" : "Kasdien",
    "Weekly" : "Kas savaitę",
    "Choose for which activities you want to get an email notification, and which should show up in the activity app stream." : "Pasirinkti kurioms veikloms norite gauti el. pašto pranešimus, ir kurios turėtų būti rodomos veiklos programėlės sraute.",
    "Settings" : "Nustatymai",
    "Enable RSS feed" : "Įjungti RSS sklaidos kanalą",
    "No more events to load" : "Nėra daugiau rodytinų įvykių",
    "Files" : "Failai",
    "Error loading activities" : "Klaida bandant parodyti veiklas",
    "No activities" : "Nėra veiklų",
    "You are receiving this email because the following things happened at %s" : "Jūs gavote pranešimą, nes įvyko šie dalykai: %s",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "_* and %n more _::_* and %n more _" : ["* ir %n kitas","* ir %n kiti","* ir %n kitų"]
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && (n%100<10 || n%100>=20) ? 1 : 2);");

==> nextcloud-12.0.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/activity/l10n/lt_LT.js <==
OC.L10N.register(
    "activity",
    {
    "Activities" : "Veiklos",
    "An error occurred while loading activities" : "Įkeliant veiklas, įvyko klaida",
    "No activity yet" : "Kol kas nėra veiklos",
    "Load more activities" : "Įkelti daugiau veiklų",
    "Copied!" : "Nukopijuota!",
    "Not supported!" : "Nepalaikoma!",
    "Press ⌘-C to copy." : "Norėdami nukopijuoti, paspauskite ⌘-C.",
    "Press Ctrl-C to copy." : "Paspauskite Ctrl-C, kad nukopijuotumėte.",
    "{name} (invisible)" : "{name} (nematomas)",
    "{name} (restricted)" : "{name} (apribotas)",
    "in {path}" : "{path}",
    "This stream will show events like additions, changes & shares" : "Srautas rodo papildymus, pakeitimus ir bendrinimus",
    "There are no events for this filter" : "Nėra įvykių pasirinktam filtrui",
    "Today" : "Šiandien",
    "Yesterday" : "Vakar",
    "Open file" : "Atverti failą",
    "Personal activity feed for %s" : "%s asmeninis veiklos kanalas",
    "Your feed URL is invalid" : "Jūsų kanalo nuoroda yra neteisinga",
    "Your settings have been updated." : "Jūsų nustatymai atnaujinti.",
    "Settings have been updated." : "Nustatymai atnaujinti.",
    "Mail" : "Paštas",
    "Stream" : "Srautas",
    "All activities" : "Visos veiklos",
    "By others" : "Kitų",
    "By you" : "Jūsų",
    "\"remote user\"" : "\"naudotojas kitame serveryje\"",
    "Hello %s" : "Sveiki, %s",
    "Hello %s," : "Sveiki, %s,",
    "There was some activity at %s" : "%s buvo veiklos",
    "_and %n more _::_and %n more _" : ["ir %n kitas","ir %n kiti","ir %n kitų"],
    "Activity notification" : "Veiklos pranešimai",
    ", " : ",",
    "%s and %s" : "%s ir %s",
    "Activity" : "Veikla",
    "Activity feed" : "Veiklos kanalas",
    "Default settings" : "Numatytieji nustatymai",
    "Configure the default activity settings for new users." : "Nustatyti numatytas veiklas naujiems naudotojams",
    "List your own actions in the stream" : "Rodyti jūsų veiklą sraute",
    "Notify about your own actions via email" : "Informuoti apie mano veiksmus per el. paštą",
    "You need to set up your email address before you can receive notification emails." : "Jums turite nurodyti elektroninio pašto adresą norėdami gauti pranešimus.",
    "Send emails:" : "Siųsti el. laiškus:",
    "As soon as possible" : "Kuo greičiau",
    "Hourly" : "Kas valandą",
    "Daily" : "Kasdien",
    "Weekly" : "Kas savaitę",
    "Choose for which activities you want to get an email notification, and which should show up in the activity app stream." : "Pasirinkti kurioms veikloms norite gauti el. pašto pranešimus, ir kurios turėtų būti rodomos veiklos programėlės sraute.",
    "Settings" : "Nustatymai",
    "Enable RSS feed" : "Įjungti RSS sklaidos kanalą",
    "RSS feed" : "RSS kanalas",
    "No more events to load" : "Nėra daugiau rodytinų įvykių",
    "Files" : "Failai",
    "Error loading activities" : "Klaida bandant parodyti veiklas",
    "No activities" : "Nėra veiklų",
    "You are receiving this email because the following things happened at %s" : "Jūs gavote pranešimą, nes įvyko šie dalykai: %s",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "_* and %n more _::_* and %n more _" : ["* ir %n kitas","* ir %n kiti","* ir %n kitų"]
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && (n%100<10 || n%100>=20) ? 1 : 2);");
